@@ -17,11 +17,11 @@ RP2_TEST_OUTPUT = {
     "B1": """GainLossSet:
   configuration=./config/test_data.config
   asset=B1
-  from_year=non-specified
-  to_year=non-specified
+  from_date=non-specified
+  to_date=non-specified
   entries=
     GainLoss:
-      id=2->None
+      id=3->None
       crypto_amount=2.00000000
       fiat_cost_basis=0.0000
       fiat_gain=24000.0000
@@ -29,7 +29,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=24000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=2
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B1
         exchange=BlockFi
@@ -42,13 +42,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=24000.0000
         is_taxable=True
         fiat_taxable_amount=24000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
       parent=None
     GainLoss:
-      id=6->None
+      id=7->None
       crypto_amount=3.00000000
       fiat_cost_basis=0.0000
       fiat_gain=39000.0000
@@ -56,7 +56,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=39000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=6
+        id=7
         timestamp=2020-03-01 09:45:00.000000 +0000
         asset=B1
         exchange=BlockFi
@@ -69,19 +69,19 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=39000.0000
         is_taxable=True
         fiat_taxable_amount=39000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=2->None""",
+      parent=3->None""",
     "B2": """GainLossSet:
   configuration=./config/test_data.config
   asset=B2
-  from_year=non-specified
-  to_year=non-specified
+  from_date=non-specified
+  to_date=non-specified
   entries=
     GainLoss:
-      id=15->3
+      id=16->4
       crypto_amount=0.20000000
       fiat_cost_basis=2220.0000
       fiat_gain=20.0000
@@ -89,7 +89,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=2240.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=OutTransaction:
-        id=15
+        id=16
         timestamp=2020-01-11 11:15:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -100,10 +100,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=2240.0000
-      from_lot_fiat_amount_with_fee_fraction=2220.0000
-      from_lot_fraction_percentage=20.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=2220.0000
+      acquired_lot_fraction_percentage=20.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -117,10 +117,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=1 of 2
+      acquired_lot_fraction=1 of 2
       parent=None
     GainLoss:
-      id=2->None
+      id=3->None
       crypto_amount=2.00000000
       fiat_cost_basis=0.0000
       fiat_gain=24000.0000
@@ -128,7 +128,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=24000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=2
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -141,13 +141,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=24000.0000
         is_taxable=True
         fiat_taxable_amount=24000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=15->3
+      parent=16->4
     GainLoss:
-      id=14->3
+      id=15->4
       crypto_amount=0.80000000
       fiat_cost_basis=8880.0000
       fiat_gain=880.0000
@@ -155,7 +155,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=9760.0000
       taxable_event_fraction_percentage=80.0000%
       taxable_event=OutTransaction:
-        id=14
+        id=15
         timestamp=2020-02-11 19:58:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -166,10 +166,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=12200.0000
-      from_lot_fiat_amount_with_fee_fraction=8880.0000
-      from_lot_fraction_percentage=80.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=8880.0000
+      acquired_lot_fraction_percentage=80.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -183,10 +183,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 2
-      from_lot_fraction=2 of 2
-      parent=2->None
+      acquired_lot_fraction=2 of 2
+      parent=3->None
     GainLoss:
-      id=14->2
+      id=15->3
       crypto_amount=0.20000000
       fiat_cost_basis=2400.0000
       fiat_gain=40.0000
@@ -194,7 +194,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=2440.0000
       taxable_event_fraction_percentage=20.0000%
       taxable_event=OutTransaction:
-        id=14
+        id=15
         timestamp=2020-02-11 19:58:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -205,10 +205,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=12200.0000
-      from_lot_fiat_amount_with_fee_fraction=2400.0000
-      from_lot_fraction_percentage=10.0000%
-      from_lot=InTransaction:
-        id=2
+      acquired_lot_fiat_amount_with_fee_fraction=2400.0000
+      acquired_lot_fraction_percentage=10.0000%
+      acquired_lot=InTransaction:
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -222,10 +222,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=True
         fiat_taxable_amount=24000.0000
       taxable_event_fraction=2 of 2
-      from_lot_fraction=1 of 2
-      parent=14->3
+      acquired_lot_fraction=1 of 2
+      parent=15->4
     GainLoss:
-      id=6->None
+      id=7->None
       crypto_amount=3.00000000
       fiat_cost_basis=0.0000
       fiat_gain=39000.0000
@@ -233,7 +233,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=39000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=6
+        id=7
         timestamp=2020-03-01 09:45:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -246,13 +246,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=39000.0000
         is_taxable=True
         fiat_taxable_amount=39000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=14->2
+      parent=15->3
     GainLoss:
-      id=16->2
+      id=17->3
       crypto_amount=1.80000000
       fiat_cost_basis=21600.0000
       fiat_gain=3960.0000
@@ -260,7 +260,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=25560.0000
       taxable_event_fraction_percentage=36.0000%
       taxable_event=OutTransaction:
-        id=16
+        id=17
         timestamp=2020-04-11 07:10:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -271,10 +271,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=71000.0000
-      from_lot_fiat_amount_with_fee_fraction=21600.0000
-      from_lot_fraction_percentage=90.0000%
-      from_lot=InTransaction:
-        id=2
+      acquired_lot_fiat_amount_with_fee_fraction=21600.0000
+      acquired_lot_fraction_percentage=90.0000%
+      acquired_lot=InTransaction:
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -288,10 +288,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=True
         fiat_taxable_amount=24000.0000
       taxable_event_fraction=1 of 3
-      from_lot_fraction=2 of 2
-      parent=6->None
+      acquired_lot_fraction=2 of 2
+      parent=7->None
     GainLoss:
-      id=16->6
+      id=17->7
       crypto_amount=3.00000000
       fiat_cost_basis=39000.0000
       fiat_gain=3600.0000
@@ -299,7 +299,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=42600.0000
       taxable_event_fraction_percentage=60.0000%
       taxable_event=OutTransaction:
-        id=16
+        id=17
         timestamp=2020-04-11 07:10:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -310,10 +310,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=71000.0000
-      from_lot_fiat_amount_with_fee_fraction=39000.0000
-      from_lot_fraction_percentage=100.0000%
-      from_lot=InTransaction:
-        id=6
+      acquired_lot_fiat_amount_with_fee_fraction=39000.0000
+      acquired_lot_fraction_percentage=100.0000%
+      acquired_lot=InTransaction:
+        id=7
         timestamp=2020-03-01 09:45:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -327,10 +327,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=True
         fiat_taxable_amount=39000.0000
       taxable_event_fraction=2 of 3
-      from_lot_fraction=1 of 1
-      parent=16->2
+      acquired_lot_fraction=1 of 1
+      parent=17->3
     GainLoss:
-      id=16->5
+      id=17->6
       crypto_amount=0.20000000
       fiat_cost_basis=2820.0000
       fiat_gain=20.0000
@@ -338,7 +338,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=2840.0000
       taxable_event_fraction_percentage=4.0000%
       taxable_event=OutTransaction:
-        id=16
+        id=17
         timestamp=2020-04-11 07:10:00.000000 +0000
         asset=B2
         exchange=BlockFi
@@ -349,10 +349,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=71000.0000
-      from_lot_fiat_amount_with_fee_fraction=2820.0000
-      from_lot_fraction_percentage=5.0000%
-      from_lot=InTransaction:
-        id=5
+      acquired_lot_fiat_amount_with_fee_fraction=2820.0000
+      acquired_lot_fraction_percentage=5.0000%
+      acquired_lot=InTransaction:
+        id=6
         timestamp=2020-04-01 09:45:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -366,10 +366,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=3 of 3
-      from_lot_fraction=1 of 3
-      parent=16->6
+      acquired_lot_fraction=1 of 3
+      parent=17->7
     GainLoss:
-      id=12->5
+      id=13->6
       crypto_amount=3.79000000
       fiat_cost_basis=53439.0000
       fiat_gain=758.0000
@@ -377,7 +377,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=54197.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=OutTransaction:
-        id=12
+        id=13
         timestamp=2020-04-12 17:50:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -388,10 +388,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=54197.0000
-      from_lot_fiat_amount_with_fee_fraction=53439.0000
-      from_lot_fraction_percentage=94.7500%
-      from_lot=InTransaction:
-        id=5
+      acquired_lot_fiat_amount_with_fee_fraction=53439.0000
+      acquired_lot_fraction_percentage=94.7500%
+      acquired_lot=InTransaction:
+        id=6
         timestamp=2020-04-01 09:45:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -405,10 +405,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=2 of 3
-      parent=16->5
+      acquired_lot_fraction=2 of 3
+      parent=17->6
     GainLoss:
-      id=13->5
+      id=14->6
       crypto_amount=0.01000000
       fiat_cost_basis=141.0000
       fiat_gain=61.0000
@@ -416,7 +416,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=202.0000
       taxable_event_fraction_percentage=0.4975%
       taxable_event=OutTransaction:
-        id=13
+        id=14
         timestamp=2021-06-11 05:31:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -427,10 +427,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.01000000
         is_taxable=True
         fiat_taxable_amount=40602.0000
-      from_lot_fiat_amount_with_fee_fraction=141.0000
-      from_lot_fraction_percentage=0.2500%
-      from_lot=InTransaction:
-        id=5
+      acquired_lot_fiat_amount_with_fee_fraction=141.0000
+      acquired_lot_fraction_percentage=0.2500%
+      acquired_lot=InTransaction:
+        id=6
         timestamp=2020-04-01 09:45:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -444,10 +444,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 2
-      from_lot_fraction=3 of 3
-      parent=12->5
+      acquired_lot_fraction=3 of 3
+      parent=13->6
     GainLoss:
-      id=13->4
+      id=14->5
       crypto_amount=2.00000000
       fiat_cost_basis=30200.0000
       fiat_gain=10200.0000
@@ -455,7 +455,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=40400.0000
       taxable_event_fraction_percentage=99.5025%
       taxable_event=OutTransaction:
-        id=13
+        id=14
         timestamp=2021-06-11 05:31:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -466,10 +466,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.01000000
         is_taxable=True
         fiat_taxable_amount=40602.0000
-      from_lot_fiat_amount_with_fee_fraction=30200.0000
-      from_lot_fraction_percentage=40.0000%
-      from_lot=InTransaction:
-        id=4
+      acquired_lot_fiat_amount_with_fee_fraction=30200.0000
+      acquired_lot_fraction_percentage=40.0000%
+      acquired_lot=InTransaction:
+        id=5
         timestamp=2020-05-01 14:03:00.000000 +0000
         asset=B2
         exchange=Coinbase
@@ -483,16 +483,16 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=2 of 2
-      from_lot_fraction=1 of 1
-      parent=13->5""",
+      acquired_lot_fraction=1 of 1
+      parent=14->6""",
     "B3": """GainLossSet:
   configuration=./config/test_data.config
   asset=B3
-  from_year=non-specified
-  to_year=non-specified
+  from_date=non-specified
+  to_date=non-specified
   entries=
     GainLoss:
-      id=25->3
+      id=26->4
       crypto_amount=0.01000000
       fiat_cost_basis=111.0000
       fiat_gain=3.0000
@@ -500,7 +500,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=114.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=IntraTransaction:
-        id=25
+        id=26
         timestamp=2020-01-21 18:33:14.342000 +0000
         asset=B3
         from_exchange=Coinbase
@@ -515,10 +515,10 @@ RP2_TEST_OUTPUT = {
         fiat_fee=114.0000
         is_taxable=True
         fiat_taxable_amount=114.0000
-      from_lot_fiat_amount_with_fee_fraction=111.0000
-      from_lot_fraction_percentage=1.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=111.0000
+      acquired_lot_fraction_percentage=1.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B3
         exchange=Coinbase
@@ -532,10 +532,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=1 of 3
+      acquired_lot_fraction=1 of 3
       parent=None
     GainLoss:
-      id=2->None
+      id=3->None
       crypto_amount=2.00000000
       fiat_cost_basis=0.0000
       fiat_gain=24000.0000
@@ -543,7 +543,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=24000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=2
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B3
         exchange=BlockFi
@@ -556,13 +556,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=24000.0000
         is_taxable=True
         fiat_taxable_amount=24000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=25->3
+      parent=26->4
     GainLoss:
-      id=6->None
+      id=7->None
       crypto_amount=3.00000000
       fiat_cost_basis=0.0000
       fiat_gain=39000.0000
@@ -570,7 +570,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=39000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=6
+        id=7
         timestamp=2020-03-01 09:45:00.000000 +0000
         asset=B3
         exchange=BlockFi
@@ -583,13 +583,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=39000.0000
         is_taxable=True
         fiat_taxable_amount=39000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=2->None
+      parent=3->None
     GainLoss:
-      id=24->3
+      id=25->4
       crypto_amount=0.02000000
       fiat_cost_basis=222.0000
       fiat_gain=66.0000
@@ -597,7 +597,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=288.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=IntraTransaction:
-        id=24
+        id=25
         timestamp=2020-05-21 12:58:10.000000 +0000
         asset=B3
         from_exchange=Coinbase
@@ -612,10 +612,10 @@ RP2_TEST_OUTPUT = {
         fiat_fee=288.0000
         is_taxable=True
         fiat_taxable_amount=288.0000
-      from_lot_fiat_amount_with_fee_fraction=222.0000
-      from_lot_fraction_percentage=2.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=222.0000
+      acquired_lot_fraction_percentage=2.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B3
         exchange=Coinbase
@@ -629,10 +629,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=2 of 3
-      parent=6->None
+      acquired_lot_fraction=2 of 3
+      parent=7->None
     GainLoss:
-      id=22->3
+      id=23->4
       crypto_amount=0.04000000
       fiat_cost_basis=444.0000
       fiat_gain=412.0000
@@ -640,7 +640,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=856.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=IntraTransaction:
-        id=22
+        id=23
         timestamp=2021-07-21 10:02:02.000000 +0000
         asset=B3
         from_exchange=Coinbase
@@ -655,10 +655,10 @@ RP2_TEST_OUTPUT = {
         fiat_fee=856.0000
         is_taxable=True
         fiat_taxable_amount=856.0000
-      from_lot_fiat_amount_with_fee_fraction=444.0000
-      from_lot_fraction_percentage=4.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=444.0000
+      acquired_lot_fraction_percentage=4.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B3
         exchange=Coinbase
@@ -672,16 +672,16 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=3 of 3
-      parent=24->3""",
+      acquired_lot_fraction=3 of 3
+      parent=25->4""",
     "B4": """GainLossSet:
   configuration=./config/test_data.config
   asset=B4
-  from_year=non-specified
-  to_year=non-specified
+  from_date=non-specified
+  to_date=non-specified
   entries=
     GainLoss:
-      id=15->3
+      id=16->4
       crypto_amount=0.20000000
       fiat_cost_basis=2220.0000
       fiat_gain=20.0000
@@ -689,7 +689,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=2240.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=OutTransaction:
-        id=15
+        id=16
         timestamp=2020-01-11 11:15:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -700,10 +700,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=2240.0000
-      from_lot_fiat_amount_with_fee_fraction=2220.0000
-      from_lot_fraction_percentage=20.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=2220.0000
+      acquired_lot_fraction_percentage=20.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -717,10 +717,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=1 of 3
+      acquired_lot_fraction=1 of 3
       parent=None
     GainLoss:
-      id=25->3
+      id=26->4
       crypto_amount=0.01000000
       fiat_cost_basis=111.0000
       fiat_gain=3.0000
@@ -728,7 +728,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=114.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=IntraTransaction:
-        id=25
+        id=26
         timestamp=2020-01-21 18:33:14.342000 +0000
         asset=B4
         from_exchange=Coinbase
@@ -743,10 +743,10 @@ RP2_TEST_OUTPUT = {
         fiat_fee=114.0000
         is_taxable=True
         fiat_taxable_amount=114.0000
-      from_lot_fiat_amount_with_fee_fraction=111.0000
-      from_lot_fraction_percentage=1.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=111.0000
+      acquired_lot_fraction_percentage=1.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -760,10 +760,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=2 of 3
-      parent=15->3
+      acquired_lot_fraction=2 of 3
+      parent=16->4
     GainLoss:
-      id=2->None
+      id=3->None
       crypto_amount=2.00000000
       fiat_cost_basis=0.0000
       fiat_gain=24000.0000
@@ -771,7 +771,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=24000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=2
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -784,13 +784,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=24000.0000
         is_taxable=True
         fiat_taxable_amount=24000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=25->3
+      parent=26->4
     GainLoss:
-      id=14->3
+      id=15->4
       crypto_amount=0.79000000
       fiat_cost_basis=8769.0000
       fiat_gain=869.0000
@@ -798,7 +798,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=9638.0000
       taxable_event_fraction_percentage=79.0000%
       taxable_event=OutTransaction:
-        id=14
+        id=15
         timestamp=2020-02-11 19:58:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -809,10 +809,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=12200.0000
-      from_lot_fiat_amount_with_fee_fraction=8769.0000
-      from_lot_fraction_percentage=79.0000%
-      from_lot=InTransaction:
-        id=3
+      acquired_lot_fiat_amount_with_fee_fraction=8769.0000
+      acquired_lot_fraction_percentage=79.0000%
+      acquired_lot=InTransaction:
+        id=4
         timestamp=2020-01-01 08:41:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -826,10 +826,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 2
-      from_lot_fraction=3 of 3
-      parent=2->None
+      acquired_lot_fraction=3 of 3
+      parent=3->None
     GainLoss:
-      id=14->2
+      id=15->3
       crypto_amount=0.21000000
       fiat_cost_basis=2520.0000
       fiat_gain=42.0000
@@ -837,7 +837,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=2562.0000
       taxable_event_fraction_percentage=21.0000%
       taxable_event=OutTransaction:
-        id=14
+        id=15
         timestamp=2020-02-11 19:58:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -848,10 +848,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=12200.0000
-      from_lot_fiat_amount_with_fee_fraction=2520.0000
-      from_lot_fraction_percentage=10.5000%
-      from_lot=InTransaction:
-        id=2
+      acquired_lot_fiat_amount_with_fee_fraction=2520.0000
+      acquired_lot_fraction_percentage=10.5000%
+      acquired_lot=InTransaction:
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -865,10 +865,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=True
         fiat_taxable_amount=24000.0000
       taxable_event_fraction=2 of 2
-      from_lot_fraction=1 of 2
-      parent=14->3
+      acquired_lot_fraction=1 of 2
+      parent=15->4
     GainLoss:
-      id=6->None
+      id=7->None
       crypto_amount=3.00000000
       fiat_cost_basis=0.0000
       fiat_gain=39000.0000
@@ -876,7 +876,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=39000.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=InTransaction:
-        id=6
+        id=7
         timestamp=2020-03-01 09:45:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -889,13 +889,13 @@ RP2_TEST_OUTPUT = {
         fiat_in_with_fee=39000.0000
         is_taxable=True
         fiat_taxable_amount=39000.0000
-      from_lot_fiat_amount_with_fee_fraction=0.0000
-      from_lot_fraction_percentage=0.0000%
-      from_lot=None
+      acquired_lot_fiat_amount_with_fee_fraction=0.0000
+      acquired_lot_fraction_percentage=0.0000%
+      acquired_lot=None
       taxable_event_fraction=1 of 1
-      parent=14->2
+      parent=15->3
     GainLoss:
-      id=16->2
+      id=17->3
       crypto_amount=1.79000000
       fiat_cost_basis=21480.0000
       fiat_gain=3938.0000
@@ -903,7 +903,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=25418.0000
       taxable_event_fraction_percentage=35.8000%
       taxable_event=OutTransaction:
-        id=16
+        id=17
         timestamp=2020-04-11 07:10:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -914,10 +914,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=71000.0000
-      from_lot_fiat_amount_with_fee_fraction=21480.0000
-      from_lot_fraction_percentage=89.5000%
-      from_lot=InTransaction:
-        id=2
+      acquired_lot_fiat_amount_with_fee_fraction=21480.0000
+      acquired_lot_fraction_percentage=89.5000%
+      acquired_lot=InTransaction:
+        id=3
         timestamp=2020-02-01 11:18:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -931,10 +931,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=True
         fiat_taxable_amount=24000.0000
       taxable_event_fraction=1 of 3
-      from_lot_fraction=2 of 2
-      parent=6->None
+      acquired_lot_fraction=2 of 2
+      parent=7->None
     GainLoss:
-      id=16->6
+      id=17->7
       crypto_amount=3.00000000
       fiat_cost_basis=39000.0000
       fiat_gain=3600.0000
@@ -942,7 +942,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=42600.0000
       taxable_event_fraction_percentage=60.0000%
       taxable_event=OutTransaction:
-        id=16
+        id=17
         timestamp=2020-04-11 07:10:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -953,10 +953,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=71000.0000
-      from_lot_fiat_amount_with_fee_fraction=39000.0000
-      from_lot_fraction_percentage=100.0000%
-      from_lot=InTransaction:
-        id=6
+      acquired_lot_fiat_amount_with_fee_fraction=39000.0000
+      acquired_lot_fraction_percentage=100.0000%
+      acquired_lot=InTransaction:
+        id=7
         timestamp=2020-03-01 09:45:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -970,10 +970,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=True
         fiat_taxable_amount=39000.0000
       taxable_event_fraction=2 of 3
-      from_lot_fraction=1 of 1
-      parent=16->2
+      acquired_lot_fraction=1 of 1
+      parent=17->3
     GainLoss:
-      id=16->5
+      id=17->6
       crypto_amount=0.21000000
       fiat_cost_basis=2961.0000
       fiat_gain=21.0000
@@ -981,7 +981,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=2982.0000
       taxable_event_fraction_percentage=4.2000%
       taxable_event=OutTransaction:
-        id=16
+        id=17
         timestamp=2020-04-11 07:10:00.000000 +0000
         asset=B4
         exchange=BlockFi
@@ -992,10 +992,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=71000.0000
-      from_lot_fiat_amount_with_fee_fraction=2961.0000
-      from_lot_fraction_percentage=5.2500%
-      from_lot=InTransaction:
-        id=5
+      acquired_lot_fiat_amount_with_fee_fraction=2961.0000
+      acquired_lot_fraction_percentage=5.2500%
+      acquired_lot=InTransaction:
+        id=6
         timestamp=2020-04-01 09:45:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1009,10 +1009,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=3 of 3
-      from_lot_fraction=1 of 2
-      parent=16->6
+      acquired_lot_fraction=1 of 2
+      parent=17->7
     GainLoss:
-      id=12->5
+      id=13->6
       crypto_amount=3.79000000
       fiat_cost_basis=53439.0000
       fiat_gain=758.0000
@@ -1020,7 +1020,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=54197.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=OutTransaction:
-        id=12
+        id=13
         timestamp=2020-04-12 17:50:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1031,10 +1031,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.00000000
         is_taxable=True
         fiat_taxable_amount=54197.0000
-      from_lot_fiat_amount_with_fee_fraction=53439.0000
-      from_lot_fraction_percentage=94.7500%
-      from_lot=InTransaction:
-        id=5
+      acquired_lot_fiat_amount_with_fee_fraction=53439.0000
+      acquired_lot_fraction_percentage=94.7500%
+      acquired_lot=InTransaction:
+        id=6
         timestamp=2020-04-01 09:45:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1048,10 +1048,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=2 of 2
-      parent=16->5
+      acquired_lot_fraction=2 of 2
+      parent=17->6
     GainLoss:
-      id=24->4
+      id=25->5
       crypto_amount=0.02000000
       fiat_cost_basis=302.0000
       fiat_gain=-14.0000
@@ -1059,7 +1059,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=288.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=IntraTransaction:
-        id=24
+        id=25
         timestamp=2020-05-21 12:58:10.000000 +0000
         asset=B4
         from_exchange=Coinbase
@@ -1074,10 +1074,10 @@ RP2_TEST_OUTPUT = {
         fiat_fee=288.0000
         is_taxable=True
         fiat_taxable_amount=288.0000
-      from_lot_fiat_amount_with_fee_fraction=302.0000
-      from_lot_fraction_percentage=0.4000%
-      from_lot=InTransaction:
-        id=4
+      acquired_lot_fiat_amount_with_fee_fraction=302.0000
+      acquired_lot_fraction_percentage=0.4000%
+      acquired_lot=InTransaction:
+        id=5
         timestamp=2020-05-01 14:03:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1091,10 +1091,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=1 of 3
-      parent=12->5
+      acquired_lot_fraction=1 of 3
+      parent=13->6
     GainLoss:
-      id=13->4
+      id=14->5
       crypto_amount=2.01000000
       fiat_cost_basis=30351.0000
       fiat_gain=10251.0000
@@ -1102,7 +1102,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=40602.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=OutTransaction:
-        id=13
+        id=14
         timestamp=2021-06-11 05:31:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1113,10 +1113,10 @@ RP2_TEST_OUTPUT = {
         crypto_fee=0.01000000
         is_taxable=True
         fiat_taxable_amount=40602.0000
-      from_lot_fiat_amount_with_fee_fraction=30351.0000
-      from_lot_fraction_percentage=40.2000%
-      from_lot=InTransaction:
-        id=4
+      acquired_lot_fiat_amount_with_fee_fraction=30351.0000
+      acquired_lot_fraction_percentage=40.2000%
+      acquired_lot=InTransaction:
+        id=5
         timestamp=2020-05-01 14:03:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1130,10 +1130,10 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=2 of 3
-      parent=24->4
+      acquired_lot_fraction=2 of 3
+      parent=25->5
     GainLoss:
-      id=22->4
+      id=23->5
       crypto_amount=0.04000000
       fiat_cost_basis=604.0000
       fiat_gain=252.0000
@@ -1141,7 +1141,7 @@ RP2_TEST_OUTPUT = {
       taxable_event_fiat_amount_with_fee_fraction=856.0000
       taxable_event_fraction_percentage=100.0000%
       taxable_event=IntraTransaction:
-        id=22
+        id=23
         timestamp=2021-07-21 10:02:02.000000 +0000
         asset=B4
         from_exchange=Coinbase
@@ -1156,10 +1156,10 @@ RP2_TEST_OUTPUT = {
         fiat_fee=856.0000
         is_taxable=True
         fiat_taxable_amount=856.0000
-      from_lot_fiat_amount_with_fee_fraction=604.0000
-      from_lot_fraction_percentage=0.8000%
-      from_lot=InTransaction:
-        id=4
+      acquired_lot_fiat_amount_with_fee_fraction=604.0000
+      acquired_lot_fraction_percentage=0.8000%
+      acquired_lot=InTransaction:
+        id=5
         timestamp=2020-05-01 14:03:00.000000 +0000
         asset=B4
         exchange=Coinbase
@@ -1173,6 +1173,6 @@ RP2_TEST_OUTPUT = {
         is_taxable=False
         fiat_taxable_amount=0.0000
       taxable_event_fraction=1 of 1
-      from_lot_fraction=3 of 3
-      parent=13->4""",
+      acquired_lot_fraction=3 of 3
+      parent=14->5""",
 }
