@@ -94,7 +94,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("11000"),
             RP2Decimal("1"),
             RP2Decimal("100.00"),
-            unique_id=3,
+            unique_id=4,
         )
         cls._in2[asset] = InTransaction(
             cls._configuration,
@@ -106,7 +106,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("12000.0"),
             RP2Decimal("2.0"),
             RP2Decimal("0"),
-            unique_id=2,
+            unique_id=3,
         )
         cls._in6[asset] = InTransaction(
             cls._configuration,
@@ -118,7 +118,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("13000.0"),
             RP2Decimal("3"),
             RP2Decimal("0"),
-            unique_id=6,
+            unique_id=7,
         )
         cls._in5[asset] = InTransaction(
             cls._configuration,
@@ -130,7 +130,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("14000.0"),
             RP2Decimal("4.0"),
             RP2Decimal("400"),
-            unique_id=5,
+            unique_id=6,
         )
         cls._in4[asset] = InTransaction(
             cls._configuration,
@@ -142,7 +142,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("15000.0"),
             RP2Decimal("5.0"),
             RP2Decimal("500"),
-            unique_id=4,
+            unique_id=5,
         )
         cls._out15[asset] = OutTransaction(
             cls._configuration,
@@ -154,7 +154,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("11200.0"),
             RP2Decimal("0.2"),
             RP2Decimal("0"),
-            unique_id=15,
+            unique_id=16,
         )
         cls._out14[asset] = OutTransaction(
             cls._configuration,
@@ -166,7 +166,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("12200.0"),
             RP2Decimal("1.0"),
             RP2Decimal("0"),
-            unique_id=14,
+            unique_id=15,
         )
         cls._out16[asset] = OutTransaction(
             cls._configuration,
@@ -178,7 +178,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("14200.00"),
             RP2Decimal("5.0"),
             RP2Decimal("0"),
-            unique_id=16,
+            unique_id=17,
         )
         cls._out12[asset] = OutTransaction(
             cls._configuration,
@@ -190,7 +190,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("14300"),
             RP2Decimal("3.79"),
             RP2Decimal("0"),
-            unique_id=12,
+            unique_id=13,
         )
         cls._out13[asset] = OutTransaction(
             cls._configuration,
@@ -202,7 +202,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("20200.00"),
             RP2Decimal("2"),
             RP2Decimal("0.01"),
-            unique_id=13,
+            unique_id=14,
         )
         cls._intra25[asset] = IntraTransaction(
             cls._configuration,
@@ -215,7 +215,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("11400.0"),
             RP2Decimal("0.1"),
             RP2Decimal("0.09"),
-            unique_id=25,
+            unique_id=26,
         )
         cls._intra24[asset] = IntraTransaction(
             cls._configuration,
@@ -228,7 +228,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("14400.0"),
             RP2Decimal("0.2"),
             RP2Decimal("0.18"),
-            unique_id=24,
+            unique_id=25,
         )
         cls._intra22[asset] = IntraTransaction(
             cls._configuration,
@@ -241,7 +241,7 @@ class TestGainLossSet(unittest.TestCase):
             RP2Decimal("21400.0"),
             RP2Decimal("0.5"),
             RP2Decimal("0.46"),
-            unique_id=22,
+            unique_id=23,
         )
         cls._gain_loss_set[asset] = GainLossSet(cls._configuration, cls._accounting_method, asset)
         if asset == "B1":
@@ -369,15 +369,15 @@ class TestGainLossSet(unittest.TestCase):
             gain_loss_set.get_taxable_event_number_of_fractions(out15)
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'transaction' is not of type InTransaction: .*"):
             # Bad get_taxable_event_fractions parameter
-            gain_loss_set.get_from_lot_number_of_fractions(None)  # type: ignore
+            gain_loss_set.get_acquired_lot_number_of_fractions(None)  # type: ignore
         with self.assertRaisesRegex(RP2TypeError, "Parameter 'transaction' is not of type InTransaction: .*"):
             # Bad get_taxable_event_fractions parameter
-            gain_loss_set.get_from_lot_number_of_fractions(self)  # type: ignore
+            gain_loss_set.get_acquired_lot_number_of_fractions(self)  # type: ignore
         with self.assertRaisesRegex(RP2ValueError, "Unknown transaction:.*"):
             # Bad get_taxable_event_fractions parameter
-            gain_loss_set.get_from_lot_number_of_fractions(in3)
+            gain_loss_set.get_acquired_lot_number_of_fractions(in3)
         with self.assertRaisesRegex(
-            RP2ValueError, "Timestamp .* of from_lot entry .* is incompatible with timestamp .* of its ancestor .* using .* accounting method: .*"
+            RP2ValueError, "Timestamp .* of acquired_lot entry .* is incompatible with timestamp .* of its ancestor .* using .* accounting method: .*"
         ):
             gain_loss_set = GainLossSet(self._configuration, self._accounting_method, asset)
             in_transaction_test: InTransaction = InTransaction(
@@ -390,14 +390,14 @@ class TestGainLossSet(unittest.TestCase):
                 RP2Decimal("12000.0"),
                 RP2Decimal("2.0"),
                 RP2Decimal("0"),
-                unique_id=2,
+                unique_id=3,
             )
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("0.2"), out15, in_transaction_test))
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("0.01"), out14, in3))
             for _ in gain_loss_set:
                 pass
         with self.assertRaisesRegex(
-            RP2ValueError, "Timestamp .* of from_lot entry .* is incompatible with timestamp .* of its ancestor .* using .* accounting method: .*"
+            RP2ValueError, "Timestamp .* of acquired_lot entry .* is incompatible with timestamp .* of its ancestor .* using .* accounting method: .*"
         ):
             gain_loss_set = GainLossSet(self._configuration, self._accounting_method, asset)
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("0.2"), out15, in_transaction_test))
@@ -421,7 +421,7 @@ class TestGainLossSet(unittest.TestCase):
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("0.2"), out15, in_transaction_test))
             for _ in gain_loss_set:
                 pass
-        with self.assertRaisesRegex(RP2ValueError, "From-lot crypto amount already exhausted for InTransaction"):
+        with self.assertRaisesRegex(RP2ValueError, "Acquired lot crypto amount already exhausted for InTransaction"):
             gain_loss_set = GainLossSet(self._configuration, self._accounting_method, asset)
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("1"), out14, in3))
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("1"), out16, in3))
@@ -433,7 +433,7 @@ class TestGainLossSet(unittest.TestCase):
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("4"), out16, in5))
             for _ in gain_loss_set:
                 pass
-        with self.assertRaisesRegex(RP2ValueError, "Current from-lot amount .* exceeded crypto balance change of from-lot .* GainLoss"):
+        with self.assertRaisesRegex(RP2ValueError, "Current acquired lot amount .* exceeded crypto balance change of acquired lot .* GainLoss"):
             gain_loss_set = GainLossSet(self._configuration, self._accounting_method, asset)
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("0.2"), out15, in3))
             gain_loss_set.add_entry(GainLoss(self._configuration, self._accounting_method, RP2Decimal("1"), out14, in3))
