@@ -29,7 +29,7 @@ class TestIntraTransaction(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls) -> None:
-        TestIntraTransaction._configuration = Configuration(US(), "./config/test_data.config")
+        TestIntraTransaction._configuration = Configuration("./config/test_data.config", US())
 
     def setUp(self) -> None:
         self.maxDiff = None  # pylint: disable=invalid-name
