@@ -30,7 +30,7 @@ class TestOutTransaction(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls) -> None:
-        TestOutTransaction._configuration = Configuration(US(), "./config/test_data.config")
+        TestOutTransaction._configuration = Configuration("./config/test_data.config", US())
 
     def setUp(self) -> None:
         self.maxDiff = None  # pylint: disable=invalid-name
